Learn R Programming

admiraldev (version 1.5.0)

admiraldev-package: admiraldev: Utility Functions and Development Tools for the Admiral Package Family

Description

logo

Utility functions to check data, variables and conditions for functions used in 'admiral' and 'admiral' extension packages. Additional utility helper functions to assist developers with maintaining documentation, testing and general upkeep of 'admiral' and 'admiral' extension packages.

Arguments

Author

Maintainer: Edoardo Mancini edoardo.mancini@roche.com (ORCID)

Authors:

Other contributors:

  • F. Hoffmann-La Roche AG [copyright holder, funder]

  • GlaxoSmithKline LLC [copyright holder, funder]

See Also