Learn R Programming

admiraldev (version 1.5.0)

enumerate: Enumerate Multiple Elements

Description

[Deprecated]

This function is deprecated, please use cli functionality instead.

Usage

enumerate(x, quote_fun = backquote, conjunction = "and")

Value

A character vector

Arguments

x

A vector or list

Default value

none

quote_fun

Quoting function, defaults to backquote. If set to NULL, the elements are not quoted.

Default value

backquote

conjunction

Character to be used in the message, defaults to "and".

Default value

"and"

See Also

Other deprecated: %or%, arg_name(), friendly_type_of(), valid_time_units(), what_is_it()