powered by
Filters the input dataset if the provided expression is not NULL
NULL
filter_if(dataset, filter)
A data.frame containing all rows in dataset matching filter or just dataset if filter is NULL
data.frame
dataset
filter
Input dataset
none
A filter condition. Must be an expression.
Developer Utility Functions: %notin%, contains_vars(), convert_dtm_to_dtc(), extract_vars(), vars2chr()
%notin%
contains_vars()
convert_dtm_to_dtc()
extract_vars()
vars2chr()