This function is deprecated, please use cli functionality instead.
friendly_type_of(x, value = TRUE, length = FALSE)A string describing the type. Starts with an indefinite article, e.g. "an integer vector".
Any R object.
none
Whether to describe the value of x.
TRUE
Whether to mention the length of vectors and lists.
FALSE
This helper function aids us in forming user-friendly messages that gets
called through what_is_it(), which is often used in the assertion functions
to identify what object-type the user passed through an argument instead of
an expected-type.
Other deprecated:
%or%,
arg_name(),
enumerate(),
valid_time_units(),
what_is_it()