@param tagThis function adds the permitted values and the default value to the
description of the @param tag. They are added as a definition list
(\describe{}).
get_param_tag(act_param, defaults)The formatted @param tag
The content of the argument description to format
A list with three named elements is expected:
tag: The @param tag
permitted: The permitted values
default: The default value
none
A list of default values from the function call
none