Skip to contents

This function provides standardized documentation text about comparing floating point numbers in conditions, e.g., PCHG <= -90.

Usage

roxygen_float_comparison()

Value

A character string with the standardized documentation text about floating point comparisons in conditions

Details

The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.

Examples

roxygen_float_comparison()
#> [1] "Comparing derived numeric variables to fixed values, e.g., `PCHG <= -90`, may give unexpected results due to floating point representation. For details and solutions see the \"Floating Point Comparisons\" section in `vignette(\"concepts_conventions\")`."