View source: R/roxygen_helpers.R
| roxygen_order_na_handling | R Documentation |
This function provides standardized documentation text about the handling
of NA values in sorting variables.
roxygen_order_na_handling()
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
A character string with the standardized documentation text about NA handling in sort order
Other documentation:
roxygen_param_by_vars(),
roxygen_param_dataset(),
roxygen_save_memory()
roxygen_order_na_handling()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.