roxygen_param_dataset: Standard Text for the 'dataset' Argument

View source: R/roxygen_helpers.R

roxygen_param_datasetR Documentation

Standard Text for the dataset Argument

Description

This function provides standardized documentation text for the dataset argument used in {admiral} functions.

Usage

roxygen_param_dataset(expected_vars = NULL)

Arguments

expected_vars

Variables expected in the dataset

A character vector of variable names expected to be present in the dataset argument.

Permitted values

A character vector or NULL

Default value

NULL

Details

The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.

Value

A character string with the standardized documentation text for the dataset argument

See Also

Other documentation: roxygen_order_na_handling(), roxygen_param_by_vars(), roxygen_save_memory()

Examples

roxygen_param_dataset()

roxygen_param_dataset(expected_vars = c("by_vars"))

admiraldev documentation built on June 10, 2026, 5:07 p.m.