roxygen_save_memory: Standard Note for Memory-Intensive Functions

View source: R/roxygen_helpers.R

roxygen_save_memoryR Documentation

Standard Note for Memory-Intensive Functions

Description

This function provides a standardized note about memory consumption for functions that create large temporary datasets.

Usage

roxygen_save_memory()

Details

The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.

Value

A character string with the standardized note about memory usage

See Also

Other documentation: roxygen_order_na_handling(), roxygen_param_by_vars(), roxygen_param_dataset()

Examples

roxygen_save_memory()

admiraldev documentation built on June 10, 2026, 5:07 p.m.