Learn R Programming

admiraldev (version 1.5.0)

valid_time_units: Valid Time Units

Description

[Deprecated]

This function is deprecated. Please get in touch if you are using this function!

Contains the acceptable character vector of valid time units

Usage

valid_time_units()

Arguments

Value

A character vector of valid time units

See Also

Other deprecated: %or%, arg_name(), enumerate(), friendly_type_of(), what_is_it()