This function is deprecated, please use cli functionality instead.
enumerate(x, quote_fun = backquote, conjunction = "and")A character vector
A vector or list
none
Quoting function, defaults to backquote. If set to NULL,
the elements are not quoted.
backquote
Character to be used in the message, defaults to "and".
"and"
Other deprecated:
%or%,
arg_name(),
friendly_type_of(),
valid_time_units(),
what_is_it()