Standard Text for Floating Point Comparisons in Conditions
Source:R/roxygen_helpers.R
roxygen_float_comparison.RdThis function provides standardized documentation text about comparing
floating point numbers in conditions, e.g., PCHG <= -90.
Value
A character string with the standardized documentation text about floating point comparisons in conditions
Details
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
See also
Other documentation:
roxygen_order_na_handling(),
roxygen_param_by_vars(),
roxygen_param_dataset(),
roxygen_save_memory()