Standard Text for NA Handling in Sorting Variables
Source:R/roxygen_helpers.R
roxygen_order_na_handling.RdThis function provides standardized documentation text about the handling
of NA values in sorting variables.
Details
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
See also
Other documentation:
roxygen_param_by_vars(),
roxygen_param_dataset(),
roxygen_save_memory()