roxygen_order_na_handling: Standard Text for NA Handling in Sorting Variables
Description
This function provides standardized documentation text about the handling
of NA values in sorting variables.
Usage
roxygen_order_na_handling()
Arguments
Value
A character string with the standardized documentation text about
NA handling in sort order
Details
The benefits of having a programmatic way to write documentation is that if
any changes need to be made, modifying this function scales across the
codebase, can be tested, and is less prone to user-error such as typos or
grammar mistakes.
See Also
Other documentation:
roxygen_param_by_vars(),
roxygen_param_dataset(),
roxygen_save_memory()