View source: R/roxygen_helpers.R
| roxygen_param_by_vars | R Documentation |
by_vars ArgumentThis function provides standardized documentation text for the by_vars
argument used in {admiral} functions.
roxygen_param_by_vars(rename = FALSE)
rename |
Should the renaming feature be documented? If
|
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
A character string with the standardized documentation text for
the by_vars argument
Other documentation:
roxygen_order_na_handling(),
roxygen_param_dataset(),
roxygen_save_memory()
roxygen_param_by_vars()
roxygen_param_by_vars(rename = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.