roxygen_param_by_vars: Standard Text for the by_vars Argument
Description
This function provides standardized documentation text for the by_vars
argument used in {admiral} functions.
Usage
roxygen_param_by_vars(rename = FALSE)
Value
A character string with the standardized documentation text for
the by_vars argument
Arguments
rename
Should the renaming feature be documented?
If TRUE, the text includes information about renaming variables using
named elements in by_vars.
Permitted values
TRUE, FALSE
Default value
FALSE
Details
The benefits of having a programmatic way to write documentation is that if
any changes need to be made, modifying this function scales across the
codebase, can be tested, and is less prone to user-error such as typos or
grammar mistakes.
See Also
Other documentation:
roxygen_order_na_handling(),
roxygen_param_dataset(),
roxygen_save_memory()