This function provides standardized documentation text for the dataset
argument used in {admiral} functions.
Details
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
See also
Other documentation:
roxygen_order_na_handling(),
roxygen_param_by_vars(),
roxygen_save_memory()
Examples
roxygen_param_dataset()
#> [1] "Input dataset"
roxygen_param_dataset(expected_vars = c("by_vars"))
#> [1] "Input dataset \n \nThe variables specified by the `by_vars` argument are expected to be in the dataset."