View source: R/roxygen_helpers.R
| roxygen_param_dataset | R Documentation |
dataset ArgumentThis function provides standardized documentation text for the dataset
argument used in {admiral} functions.
roxygen_param_dataset(expected_vars = NULL)
expected_vars |
Variables expected in the dataset A character vector of variable names expected to be present in the
|
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
A character string with the standardized documentation text for
the dataset argument
Other documentation:
roxygen_order_na_handling(),
roxygen_param_by_vars(),
roxygen_save_memory()
roxygen_param_dataset()
roxygen_param_dataset(expected_vars = c("by_vars"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.