View source: R/roxygen_helpers.R
| roxygen_save_memory | R Documentation |
This function provides a standardized note about memory consumption for functions that create large temporary datasets.
roxygen_save_memory()
The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.
A character string with the standardized note about memory usage
Other documentation:
roxygen_order_na_handling(),
roxygen_param_by_vars(),
roxygen_param_dataset()
roxygen_save_memory()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.