Learn R Programming

admiraldev (version 1.5.0)

roxygen_save_memory: Standard Note for Memory-Intensive Functions

Description

This function provides a standardized note about memory consumption for functions that create large temporary datasets.

Usage

roxygen_save_memory()

Arguments

Value

A character string with the standardized note about memory usage

Details

The benefits of having a programmatic way to write documentation is that if any changes need to be made, modifying this function scales across the codebase, can be tested, and is less prone to user-error such as typos or grammar mistakes.

See Also

Other documentation: roxygen_order_na_handling(), roxygen_param_by_vars(), roxygen_param_dataset()

Examples

Run this code
roxygen_save_memory()

Run the code above in your browser using DataLab