powered by
This function is deprecated. Please get in touch if you are using this function!
Contains the acceptable character vector of valid time units
valid_time_units()
A character vector of valid time units
character
Other deprecated: %or%, arg_name(), enumerate(), friendly_type_of(), what_is_it()
%or%
arg_name()
enumerate()
friendly_type_of()
what_is_it()